<?php

$lan = array(
  'You do not have access to this page' => 'Voc&ecirc; n&atilde;o tem acesso a esta p&aacute;gina',
  'Select Message to view' => 'Selecione a Mensagem para Exibi-la',
  'Available Messages' => 'Mensagens Dispon&iacute;veis',
  'There are currently no messages to view' => 'Nenhuma mensagem',
  'bounced' => 'erros',
  'views' => 'exibidas',
  'rate' => 'taxa',
  'Comparison to other admins' => 'Comparar com outros administradores',
  'View Details for a Message' => 'Exibir os Detalhes de uma Mensagem',
  'Subject' => 'Assunto',
  'Entered' => 'Inserido',
  'Message Open Statistics' => 'Abrir as Estat&iacute;sticas da Mensagem',
  'Listing user %d to %d' => 'Listando usu&aacute;rios de %d a %d',
  'Entries' => 'Entradas',
  'firstview' => 'vista pela primeira vez em',
  'lastview' => '&Uacute;ltima vez em que foi exibida',
  'views' => 'exibidas',
  'responsetime' => 'tempo de resposta',
  'sec' => 'sec',
);

?>
